Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(48)

Unified Diff: chromeos/dbus/auth_policy_client.h

Issue 2491153003: Add Refresh{Device,User}Policies methods into AuthPolicyClient (Closed)
Patch Set: Addressed comments Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chromeos/dbus/auth_policy_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/auth_policy_client.h
diff --git a/chromeos/dbus/auth_policy_client.h b/chromeos/dbus/auth_policy_client.h
index 550edea4e9eb75ecb573fdaf59f6d078a4ff1d69..740d6af3bd2ebfbeff215c48edfde2b3a19c9de9 100644
--- a/chromeos/dbus/auth_policy_client.h
+++ b/chromeos/dbus/auth_policy_client.h
@@ -29,6 +29,7 @@ namespace chromeos {
class CHROMEOS_EXPORT AuthPolicyClient : public DBusClient {
public:
using JoinCallback = base::Callback<void(int error_code)>;
+ using RefreshPolicyCallback = base::Callback<void(bool success)>;
~AuthPolicyClient() override;
@@ -36,17 +37,28 @@ class CHROMEOS_EXPORT AuthPolicyClient : public DBusClient {
// For normal usage, access the singleton via DBusThreadManager::Get().
static AuthPolicyClient* Create();
// TODO(rsorokin): Write more descriptive comment.
// Calls JoinADDomain. Uses |machine_name| to join it to the domain. |user|,
// |password_fd| are credentials of the AD user which have right to join the
// domain. |password_fd| is a file descriptor password is read from.
// The caller should close it after the call.
// |callback| is called after the method call succeeds.
virtual void JoinAdDomain(const std::string& machine_name,
const std::string& user,
int password_fd,
const JoinCallback& callback) = 0;
+ // Calls RefreshDevicePolicy - handle policy for the device.
+ // Fetch GPO files from Active directory server, parse it, encode it into
+ // protobuf and send to SessionManager. Callback is called after that.
+ virtual void RefreshDevicePolicy(const RefreshPolicyCallback& callback) = 0;
+
+ // Calls RefreshUserPolicy - handle policy for the user specified by
+ // |account_id|. Similar to RefreshDevicePolicy.
+ virtual void RefreshUserPolicy(const std::string& account_id,
+ const RefreshPolicyCallback& callback) = 0;
+
protected:
// Create() should be used instead.
AuthPolicyClient();
@@ -36,17 +37,28 @@ class CHROMEOS_EXPORT AuthPolicyClient : public DBusClient {
// For normal usage, access the singleton via DBusThreadManager::Get().
static AuthPolicyClient* Create();
- // TODO(rsorokin): Write more descriptive comment.
- // Calls JoinADDomain. Uses |machine_name| to join it to the domain. |user|,
- // |password_fd| are credentials of the AD user which have right to join the
- // domain. |password_fd| is a file descriptor password is read from.
- // The caller should close it after the call.
+ // Calls JoinADDomain. It runs "net ads join ..." which joins machine to
+ // Active directory domain.
+ // |machine_name| is a name for a local machine. |user|,
+ // |password_fd| are credentials of the Active directory account which has
+ // right to join the machine to the domain. |password_fd| is a file descriptor
+ // password is read from. The caller should close it after the call.
// |callback| is called after the method call succeeds.
virtual void JoinAdDomain(const std::string& machine_name,
« no previous file with comments | « no previous file | chromeos/dbus/auth_policy_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698